@@ -12,6 +12,22 @@ master_doc = "index"
 
 # -- Options for HTML output ---------------------------------------------------
 
+# Add any Sphinx extension module names here, as strings. They can be extensions
+# coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
+extensions = [
+    "sphinx.ext.autodoc",
+    "sphinx.ext.imgmath",
+    "sphinx.ext.viewcode",
+]
+
+# The theme to use for HTML and HTML Help pages.  See the documentation for
+# a list of builtin themes.
+html_theme = "sphinx_mdolab_theme"
+
+html_theme_options = {
+    "titles_only": True,
+}
+
 # Add any paths that contain custom static files (such as style sheets) here,
 # relative to this directory. They are copied after the builtin static files,
 # so a file named "default.css" will overwrite the builtin "default.css".
